#=====================================================================================================#
# -*- coding:Utf-8 -*-

# FileAnalyse.py (16/12/2007)
# remerciemmment spéciale a NICOLOUS
# MATTIE'S EVENTSCRIPTS 2.0, PYTHON OPERATIONNEL

# PLUGIN = http://mattie.info/cs
# analyseur de fichiers 'text' & 'config' = http://forums.mattie.info/cs/forums/viewtopic.php?t=18920





#           CLASS
#-----------------------------------------------------------------------------------------------------#

#  PUBLIC : FileAnalyse.py  #

import es, os, re, psyco
psyco.full()

class FileAnalyse:
    """
        Classe public: analyse un fichier de type 'text' ou 'config'

        Propose un système de récupération du contenu d'un fichier en lecture seule, 
        tout en ignorant les commentaires et en supprimant ce qui est génant 
        (espaces, tabulations, retours chariots, etc...).

        Exemple d'utilisation :

        from FileAnalyse import FileAnalyse

        - Analyser le fichier : fichieranalyse = FileAnalyse("root:/mondossier/monfichier.txt/cfg")
        - Obtenir la liste : fichierliste = fichieranalyse.getList()

        - Exemple eventscript : maconfig = FileAnalyse(WelcomSound.scritpDir() + "/sound.cfg").getList()
    """


    def __init__(self,racineDuFichier): 
        """
            Analyse et récupère les lignes d'un fichier dont le nom est donné en paramètre
        """

        # On essai l'ouverture du fichier
        try:
            # Ouverture du fichier
            readfile = open(racineDuFichier, "r")

            # Lecture du fichier dépourvu de retours chariots windows
            self.read=readfile.read().split("\n")

            # Analyse du fichier
            self.__analyse()

            # Fermeture du fichier
            readfile.close()

        # Si l'essai a échoué, IOError indiquera la cause, log éventuel.
        except IOError:
            # Le fichier n'a peu etre lus. information écrite dans les logs du serveur
            es.log("[LOG FileAnalyse.py] - lecture impossible du fichier: " + racineDuFichier)

            # j'ai pas encore totalemment percé le secret de 'raise'
            raise


    def __analyse(self):
        """
            Méthode privé d'analyse ligne par ligne du fichier
        """

        # Variable local indispensable à la méthode d'analyse représentant l'index de la liste
        lineindex = 0

        # Pour chaques éléments de la liste
        while lineindex < len(self.read):

            # Analyse des commantaires de la ligne
            self.read[lineindex] = self.__comment(self.read[lineindex])

            # Analyse des espaces et tabulations de la ligne
            self.read[lineindex] = self.__spantab(self.read[lineindex])

            # Analyse des retours chariots linux de la ligne
            self.read[lineindex] = self.__returns(self.read[lineindex])

            # Analyse des commantaires de la ligne
            self.read[lineindex] = self.__accents(self.read[lineindex])

            # Suppression de la ligne si elle est vide après l'analyse
            if not str(self.read[lineindex]):
                self.read.remove(self.read[lineindex])

            # Sinon, incrémantation de 'l'index'
            else:
                lineindex += 1


    @staticmethod
    def __comment(comment):
        """
            Fonction static privé. Objectif: supprimmer les commantaires d'une ligne
        """

        return re.sub("//.*", "", comment)


    @staticmethod
    def __spantab(spantab):
        """
            Fonction privé. Objectif: supprimmer les espaces et tabulations inutile
        """

        return re.sub("^(( |\t)+)|(( |\t)+)$", " ", spantab)


    @staticmethod
    def __returns(returns):
        """
            Fonction privé. Objectif: supprimmer les retours chariots linux
        """

        return returns.replace("\r", "")


    @staticmethod
    def __accents(accents):
        """
            Fonction privé. Objectif: supprimmer les guillemets d'une ligne
        """

        return accents.replace('"', "")


    def getList(self):
        """
            Fonction public. Accesseur : liste des lignes d'un fichier après analyse.
        """

        # Si la liste est vide
        if not self.read[:]:
            # Information écrite dans les logs du serveur
            es.log("[LOG FileAnalyse.py] - La liste est vide")

        # Liste de configuration dans une liste
        return self.read[:]

#=====================================================================================================#
